Errors
======

.. note::

  The documentation in this section is aimed at people wishing to contribute to
  :mod:`hubugs`, and can be skipped if you are simply using the tool from the
  command line.

.. autoexception:: hubugs.template.EmptyMessageError

.. autoexception:: hubugs.utils.HttpClientError
.. autoexception:: hubugs.utils.RepoError
